==> sutty-archives-2.2.2.gem: lib/jekyll-archives/archive.rb <==
# frozen_string_literal: true

module Jekyll
  module Archives
    class Archive < Jekyll::Page
      attr_accessor :posts, :type, :slug

      # Attributes for Liquid templates
      ATTRIBUTES_FOR_LIQUID = %w(
        posts
        type
        title
        date
        name
        path
        url
        permalink
        slug
        category
        tag
      ).freeze

      # Initialize a new Archive page
      #
      # site  - The Site object.
      # title - The name of the tag/category or a Hash of the year/month/day in case of date.
      #           e.g. { :year => 2014, :month => 08 } or "my-category" or "my-tag".
      # type  - The type of archive. Can be one of "year", "month", "day", "category", or "tag"
      # posts - The array of posts that belong in this archive.
      def initialize(site, title, type, posts)
        @site   = site
        @posts  = posts
        @type   = type
        @title  = title
        @config = site.config["jekyll-archives"]
        @slug   = slugify_string_title

        # Use ".html" for file extension and url for path
        @ext  = File.extname(relative_path)
        @path = relative_path
        @name = File.basename(relative_path, @ext)

        @data = {
          "layout" => layout,
        }
        @content = ""
      end

      # The template of the permalink.
      #
      # Returns the template String.
      def template
        t = @config.dig("permalinks", type)
        t = t.is_a?(Hash) ? t[title] : t

        t || "/#{type}/:name/"
      end

      # The layout to use for rendering
      #
      # Returns the layout as a String
      def layout
        @config.dig("layouts", type) || @config["layout"]
      end

      # Returns a hash of URL placeholder names (as symbols) mapping to the
      # desired placeholder replacements. For details see "url.rb".
      def url_placeholders
        if @title.is_a? Hash
          placeholders = @title.merge(:type => @type)

          if @type == 'category-tag'
            %i[category tag].each do |k|
              placeholders[k] = Utils.slugify(@title[k], mode: @config.dig('slug'))
            end
          end

          placeholders
        else
          { :name => @slug, :type => @type }
        end
      end

      # The generated relative url of this page. e.g. /about.html.
      #
      # Returns the String url.
      def url
        @url ||= URL.new(
          :template     => template,
          :placeholders => url_placeholders,
          :permalink    => nil
        ).to_s
      rescue ArgumentError
        raise ArgumentError, "Template \"#{template}\" provided is invalid."
      end

      def permalink
        data&.is_a?(Hash) && data["permalink"]
      end

      # Produce a title object suitable for Liquid based on type of archive.
      #
      # Returns a String (for tag and category archives) and nil for
      # date-based archives.
      def title
        if @title.is_a? String
          @title
        elsif @type == 'category-tag'
          @title.values.join(@config.fetch('separator', ' / '))
        end
      end

      # Produce a date object if a date-based archive
      #
      # Returns a Date.
      def date
        return unless date?

        @date ||= begin
          args = @title.values.map(&:to_i)
          Date.new(*args)
        end
      end

      def category
        @title[:category] if @title.is_a? Hash
      end

      def tag
        @title[:tag] if @title.is_a? Hash
      end

      # Obtain the write path relative to the destination directory
      #
      # Returns the destination relative path String.
      def relative_path
        @relative_path ||= begin
          path = URL.unescape_path(url).gsub(%r!^/!, "")
          path = File.join(path, "index.html") if url.end_with?("/")
          path
        end
      end

      # Returns the object as a debug String.
      def inspect
        "#<Jekyll:Archive @type=#{@type} @title=#{@title} @data=#{@data.inspect}>"
      end

      def date?
        %w[year month day].include? @type
      end

      private

      # Generate slug if @title attribute is a string.
      #
      # Note: mode other than those expected by Jekyll returns the given string after
      # downcasing it.
      def slugify_string_title
        return unless title.is_a?(String)

        mode = @config["slug_mode"] || @config["slug"]

        Utils.slugify(title, :mode => mode)
      end
    end
  end
end

==> sutty-archives-2.2.3.gem: lib/jekyll-archives/archive.rb <==
# frozen_string_literal: true

module Jekyll
  module Archives
    class Archive < Jekyll::Page
      attr_accessor :posts, :type, :slug

      # Attributes for Liquid templates
      ATTRIBUTES_FOR_LIQUID = %w(
        posts
        type
        title
        date
        name
        path
        url
        permalink
        slug
        category
        tag
      ).freeze

      # Initialize a new Archive page
      #
      # site  - The Site object.
      # title - The name of the tag/category or a Hash of the year/month/day in case of date.
      #           e.g. { :year => 2014, :month => 08 } or "my-category" or "my-tag".
      # type  - The type of archive. Can be one of "year", "month", "day", "category", or "tag"
      # posts - The array of posts that belong in this archive.
      def initialize(site, title, type, posts)
        @site   = site
        @posts  = posts
        @type   = type
        @title  = title
        @config = site.config["jekyll-archives"]
        @slug   = slugify_string_title

        # Use ".html" for file extension and url for path
        @ext  = File.extname(relative_path)
        @path = relative_path
        @name = File.basename(relative_path, @ext)

        @data = { "layout" => layout }

        @content = ""
      end

      # The template of the permalink.
      #
      # Returns the template String.
      def template
        t = @config.dig("permalinks", type)
        t = t.is_a?(Hash) ? t[@title] : t

        t || "/#{type}/:name/"
      end

      # The layout to use for rendering
      #
      # Returns the layout as a String
      def layout
        @config.dig("layouts", type) || @config["layout"]
      end

      # Returns a hash of URL placeholder names (as symbols) mapping to the
      # desired placeholder replacements. For details see "url.rb".
      def url_placeholders
        if @title.is_a? Hash
          placeholders = @title.merge(:type => @type)

          if @type == 'category-tag'
            %i[category tag].each do |k|
              placeholders[k] = Utils.slugify(@title[k], mode: @config.dig('slug'))
            end
          end

          placeholders
        else
          { :name => @slug, :type => @type }
        end
      end

      # The generated relative url of this page. e.g. /about.html.
      #
      # Returns the String url.
      def url
        @url ||= URL.new(
          :template     => template,
          :placeholders => url_placeholders,
          :permalink    => nil
        ).to_s
      rescue ArgumentError
        raise ArgumentError, "Template \"#{template}\" provided is invalid."
      end

      def permalink
        data&.is_a?(Hash) && data["permalink"]
      end

      # Produce a title object suitable for Liquid based on type of archive.
      #
      # Returns a String (for tag and category archives) and nil for
      # date-based archives.
      def title
        if @title.is_a? String
          @config.dig('titles', @title) || @title
        elsif @type == 'category-tag'
          @title.values.join(@config.fetch('separator', ' / '))
        end
      end

      # Produce a date object if a date-based archive
      #
      # Returns a Date.
      def date
        return unless date?

        @date ||= begin
          args = @title.values.map(&:to_i)
          Date.new(*args)
        end
      end

      def category
        @title[:category] if @title.is_a? Hash
      end

      def tag
        @title[:tag] if @title.is_a? Hash
      end

      # Obtain the write path relative to the destination directory
      #
      # Returns the destination relative path String.
      def relative_path
        @relative_path ||= begin
          path = URL.unescape_path(url).gsub(%r!^/!, "")
          path = File.join(path, "index.html") if url.end_with?("/")
          path
        end
      end

      # Returns the object as a debug String.
      def inspect
        "#<Jekyll:Archive @type=#{@type} @title=#{@title} @data=#{@data.inspect}>"
      end

      def date?
        %w[year month day].include? @type
      end

      private

      # Generate slug if @title attribute is a string.
      #
      # Note: mode other than those expected by Jekyll returns the given string after
      # downcasing it.
      def slugify_string_title
        return unless title.is_a?(String)

        mode = @config["slug_mode"] || @config["slug"]

        Utils.slugify(title, :mode => mode)
      end
    end
  end
end
